==> apb-project_2.12-0.2.0-sources.jar: org/mulesoft/apb/project/client/scala/dependency/ParsedDependency.scala <==
package org.mulesoft.apb.project.client.scala.dependency

import amf.aml.client.scala.model.document.{Dialect, DialectInstance}
import amf.core.client.common.validation.SeverityLevels
import amf.core.client.scala.model.document.{BaseUnit, ExternalFragment}
import amf.core.client.scala.validation.AMFValidationResult
import amf.core.client.scala.vocabulary.Namespace
import org.mulesoft.apb.project.client.scala.ProjectErrors
import org.mulesoft.apb.project.internal.validations.ProjectValidations.UnreacheableAsset
import org.mulesoft.apb.project.internal.dependency.UnreachableDependency.emptyUnit
import org.mulesoft.apb.project.client.scala.model._

abstract class ParsedDependency(val baseUnit: BaseUnit, val descriptor: ProjectDescriptor, val errors: ProjectErrors) {
  val scope: DependencyScope
  val location: String = baseUnit.location().getOrElse(baseUnit.id)
}

case class DesignDependency(override val baseUnit: BaseUnit,
                            override val descriptor: ProjectDescriptor,
                            override val errors: ProjectErrors)
    extends ParsedDependency(baseUnit, descriptor, errors) {
  override val scope: DependencyScope = DesignScope
}

case class ExtensionDependency(dialect: Dialect,
                               override val descriptor: ProjectDescriptor,
                               override val errors: ProjectErrors)
    extends ParsedDependency(dialect, descriptor, errors) {
  override val scope: DependencyScope = ExtensionScope
}

case class ProfileDependency(profile: DialectInstance,
                             override val descriptor: ProjectDescriptor,
                             override val errors: ProjectErrors)
    extends ParsedDependency(profile, descriptor, errors) {
  override val scope: DependencyScope = ValidationScope

  val profileName: String = Option(profile.encodes)
    .flatMap(
      _.graph
        .scalarByProperty((Namespace("http://schema.org/") + "name").iri())
        .headOption
        .map(_.toString))
    .getOrElse("Unknown")
}

==> apb-project_2.12-0.2.1-sources.jar: org/mulesoft/apb/project/client/scala/dependency/ParsedDependency.scala <==
package org.mulesoft.apb.project.client.scala.dependency

import amf.aml.client.scala.model.document.{Dialect, DialectInstance}
import amf.core.client.scala.model.document.BaseUnit
import amf.core.client.scala.vocabulary.Namespace
import org.mulesoft.apb.project.client.scala.ProjectErrors
import org.mulesoft.apb.project.client.scala.model._

trait Dependency {
  val descriptor: ProjectDescriptor
  val errors: ProjectErrors
}

case class NotParsedDependency(descriptor: ProjectDescriptor, errors: ProjectErrors) extends Dependency

abstract class ParsedDependency(val baseUnit: BaseUnit, val descriptor: ProjectDescriptor, val errors: ProjectErrors)
    extends Dependency {
  val scope: DependencyScope
  val location: String = baseUnit.location().getOrElse(baseUnit.id)
}

case class DesignDependency(override val baseUnit: BaseUnit,
                            override val descriptor: ProjectDescriptor,
                            override val errors: ProjectErrors)
    extends ParsedDependency(baseUnit, descriptor, errors) {
  override val scope: DependencyScope = DesignScope
}

case class ExtensionDependency(dialect: Dialect,
                               override val descriptor: ProjectDescriptor,
                               override val errors: ProjectErrors)
    extends ParsedDependency(dialect, descriptor, errors) {
  override val scope: DependencyScope = ExtensionScope
}

case class ProfileDependency(profile: DialectInstance,
                             override val descriptor: ProjectDescriptor,
                             override val errors: ProjectErrors)
    extends ParsedDependency(profile, descriptor, errors) {
  override val scope: DependencyScope = ValidationScope

  val profileName: String = Option(profile.encodes)
    .flatMap(
      _.graph
        .scalarByProperty((Namespace("http://schema.org/") + "name").iri())
        .headOption
        .map(_.toString))
    .getOrElse("Unknown")
}

case class ProvidedDependency(project: Gav, provided: Gav)
